@@ -28,7 +28,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "q_ctype.h"
 #include <errno.h>
 
-#include "miniz.h"
+// Plug our allocators into miniz:
+#define MZ_MALLOC(x)	 Mem_Alloc (x)
+#define MZ_FREE(x)		 Mem_Free (x)
+#define MZ_REALLOC(p, x) Mem_Realloc (p, x)
+
+// include miniz stb-syle, directly in this compilation unit.
+// (supported by miniz)
+#include "miniz.c"
 
 static char *largv[MAX_NUM_ARGVS + 1];
 static char	 argvdummy[] = " ";
@@ -54,7 +61,7 @@ static void COM_Path_f (void);
 #define PAK0_COUNT_V091 308	  /* id1/pak0.pak - v0.91/0.92, not supported */
 #define PAK0_CRC_V091	28804 /* id1/pak0.pak - v0.91/0.92, not supported */
 
-THREAD_LOCAL char com_token[1024];
+THREAD_LOCAL char com_token[COM_PARSE_MAX_TOKEN_SIZE];
 int				  com_argc;
 char			**com_argv;
 
@@ -199,6 +206,69 @@ void Vec_Free (void **pvec)
 ============================================================================
 */
 
+int q_strnaturalcmp (const char *s1, const char *s2)
+{
+	qboolean neg1, neg2, sign1, sign2;
+
+	if (s1 == s2)
+		return 0;
+
+	neg1 = *s1 == '-';
+	neg2 = *s2 == '-';
+	sign1 = neg1 || *s1 == '+';
+	sign2 = neg2 || *s2 == '+';
+
+	// early out if strings start with different signs followed by digits
+	if (neg1 != neg2 && q_isdigit (s1[sign1]) && q_isdigit (s1[sign2]))
+		return neg2 - neg1;
+
+skip_prefix:
+	while (*s1 && !q_isdigit (*s1) && q_toupper (*s1) == q_toupper (*s2))
+	{
+		s1++;
+		s2++;
+		continue;
+	}
+
+	if (q_isdigit (*s1) && q_isdigit (*s2))
+	{
+		const char *begin1 = s1++;
+		const char *begin2 = s2++;
+		int			diff, sign;
+
+		while (*begin1 == '0')
+			begin1++;
+		while (*begin2 == '0')
+			begin2++;
+
+		while (q_isdigit (*s1))
+			s1++;
+		while (q_isdigit (*s2))
+			s2++;
+
+		sign = neg1 ? -1 : 1;
+
+		diff = (s1 - begin1) - (s2 - begin2);
+		if (diff)
+			return diff * sign;
+
+		while (begin1 != s1)
+		{
+			diff = *begin1++ - *begin2++;
+			if (diff)
+				return diff * sign;
+		}
+
+		// We only support negative numbers at the beginning of strings so that
+		// "-2" is sorted before "-1", but "file-2345.ext" *after* "file-1234.ext".
+		neg1 = neg2 = false;
+
+		goto skip_prefix;
+	}
+
+	return q_toupper (*s1) - q_toupper (*s2);
+}
+
 int q_strcasecmp (const char *s1, const char *s2)
 {
 	const char *p1 = s1;
@@ -281,6 +351,113 @@ char *q_strupr (char *str)
 	return str;
 }
 
+char *q_strtrim (char *str)
+{
+	// trim leading and ending whitespaces:
+	char *str_start = (char *)str;
+
+	// trim leading:
+	while (q_isspace ((unsigned char)*str))
+		str++;
+
+	// trim ending :
+	size_t last_index = strlen (str_start) - 1;
+
+	while (last_index >= 0)
+	{
+		if (q_isspace (str_start[last_index]))
+		{
+			str_start[last_index] = '\0';
+		}
+		else
+		{
+			break;
+		}
+		last_index--;
+	}
+
+	return str;
+}
+
+static bool is_in_char_set (char single_char, const char *char_set)
+{
+	const size_t char_set_size = strlen (char_set);
+
+	for (size_t char_index = 0; char_index < char_set_size; char_index++)
+	{
+		if (char_set[char_index] == single_char)
+			return true;
+	}
+
+	return false;
+}
+
+char **q_strsplit (char *str, const char *sep_set, size_t *nb_substr)
+{
+	size_t nb_sub_strings_max_size = 8;
+	char **sub_strings = Mem_Alloc (nb_sub_strings_max_size * sizeof (char *));
+	int	   nb_sub_strings = 0;
+
+	size_t start_str_index = 0;
+
+	// special case, gobble the leading sep characters:
+	while (is_in_char_set (str[start_str_index], sep_set))
+	{
+		str[start_str_index] = 0;
+		start_str_index++;
+	}
+	// the real start of the string is here
+	char *str_start = &str[start_str_index];
+
+	// always return a valid memory although  nb_sub_strings = 0
+	// so that the caller is not burdened with NULL checks.
+	//  TODO: or more explicit if it would ?
+	assert (nb_sub_strings == 0);
+	if (!str_start)
+		return sub_strings;
+
+	const size_t initial_str_size = strlen (str_start);
+
+	for (size_t char_index = 0; char_index < initial_str_size; char_index++)
+	{
+		// find the next sep
+		if (is_in_char_set (str_start[char_index], sep_set))
+		{
+			// goble consecutive seps, if any
+			while (is_in_char_set (str_start[char_index], sep_set))
+			{
+				// split the original string
+				str_start[char_index] = 0;
+				char_index++;
+			}
+			//
+			if (char_index <= initial_str_size)
+			{
+				// make room
+				if (nb_sub_strings >= nb_sub_strings_max_size)
+				{
+					nb_sub_strings_max_size = nb_sub_strings_max_size * 2;
+					sub_strings = Mem_Realloc (sub_strings, nb_sub_strings_max_size * sizeof (char *));
+				}
+				// we found the first split, meaning the string before this split is indeed the first sub-string
+				if (nb_sub_strings == 0)
+					sub_strings[nb_sub_strings++] = &str_start[0];
+
+				if (char_index < initial_str_size)
+					sub_strings[nb_sub_strings++] = &str_start[char_index];
+			}
+		}
+	}
+
+	// no split, return the original string stripped from its leadings seps
+	if (nb_sub_strings == 0)
+		sub_strings[nb_sub_strings++] = &str_start[0];
+
+	*nb_substr = nb_sub_strings;
+
+	return sub_strings;
+}
+
 char *q_strdup (const char *str)
 {
 	size_t len = strlen (str) + 1;
@@ -1529,13 +1706,12 @@ void COM_Init (void)
 ============
 va
 
-does a varargs printf into a temp buffer. cycles between
-4 different static buffers. the number of buffers cycled
-is defined in VA_NUM_BUFFS.
+does a varargs printf into a temp buffer. Cycles between
+VA_NUM_BUFFS different static buffers.
 FIXME: make this buffer size safe someday
 ============
 */
-#define VA_NUM_BUFFS 4
+#define VA_NUM_BUFFS 8
 #if (MAX_OSPATH >= 1024)
 #define VA_BUFFERLEN MAX_OSPATH
 #else
@@ -1780,12 +1956,26 @@ static int COM_FindFile (const char *filename, int *handle, FILE **file, unsigne
 		}
 	}
 
-	if (strcmp (COM_FileGetExtension (filename), "pcx") != 0 && strcmp (COM_FileGetExtension (filename), "tga") != 0 &&
-		strcmp (COM_FileGetExtension (filename), "lit") != 0 && strcmp (COM_FileGetExtension (filename), "vis") != 0 &&
-		strcmp (COM_FileGetExtension (filename), "ent") != 0)
-		Con_DPrintf ("FindFile: can't find %s\n", filename);
-	else
-		Con_DPrintf2 ("FindFile: can't find %s\n", filename);
+	if (developer.value)
+	{
+		const char *ext = COM_FileGetExtension (filename);
+
+		if (strcmp (ext, "pcx") != 0 && strcmp (ext, "tga") != 0 && strcmp (ext, "png") != 0 && strcmp (ext, "jpg") != 0 && strcmp (ext, "lmp") != 0 &&
+			// music formats
+			strcmp (ext, "ogg") != 0 && strcmp (ext, "opus") != 0 && strcmp (ext, "flac") != 0 && strcmp (ext, "wav") != 0 && strcmp (ext, "it") != 0 &&
+			strcmp (ext, "s3m") != 0 && strcmp (ext, "xm") != 0 && strcmp (ext, "mod") != 0 && strcmp (ext, "umx") != 0 &&
+			// alternate model formats
+			strcmp (ext, "md5mesh") != 0 && strcmp (ext, "md3") != 0 && strcmp (ext, "skin") != 0 &&
+			// optional map files
+			strcmp (ext, "lit") != 0 && strcmp (ext, "vis") != 0 && strcmp (ext, "ent") != 0)
+		{
+			Con_DPrintf ("FindFile: can't find %s\n", filename);
+		}
+		else
+		{
+			Con_DPrintf2 ("FindFile: can't find %s\n", filename);
+		}
+	}
 
 	if (handle)
 		*handle = -1;
@@ -1997,10 +2187,6 @@ Loads the header and directory, adding the files at the beginning
 of the list so they override previous pack files.
 =================
 */
-// use tglobal as temporary to prevent stack consumption,
-// fine because this is only called from the main loop.
-static dpackfile_t info[MAX_FILES_IN_PACK];
-
 static pack_t *COM_LoadPackFile (const char *packfile, int packhandle)
 {
 	dpackheader_t  header;
@@ -2010,6 +2196,10 @@ static pack_t *COM_LoadPackFile (const char *packfile, int packhandle)
 	pack_t		  *pack;
 	unsigned short crc;
 
+	// use global as temporary to prevent stack consumption,
+	// fine because this is only called from the main loop.
+	static dpackfile_t info[MAX_FILES_IN_PACK];
+
 	Sys_FileRead (packhandle, (void *)&header, sizeof (header));
 	if (header.id[0] != 'P' || header.id[1] != 'A' || header.id[2] != 'C' || header.id[3] != 'K')
 		Sys_Error ("%s is not a packfile", packfile);
@@ -2192,9 +2382,12 @@ _add_path:
 				tinfl_decompressor inflator;
 				tinfl_init (&inflator);
 				vkquake_pak_extracted = Mem_Alloc (vkquake_pak_size_extracted);
-				if (TINFL_STATUS_DONE != tinfl_decompress (
-											 &inflator, vkquake_pak, &vkquake_pak_size_compressed, vkquake_pak_extracted, vkquake_pak_extracted,
-											 &vkquake_pak_size_extracted, TINFL_FLAG_USING_NON_WRAPPING_OUTPUT_BUF))
+
+				tinfl_status decomp_status = tinfl_decompress (
+					&inflator, vkquake_pak, &vkquake_pak_size_compressed, vkquake_pak_extracted, vkquake_pak_extracted, &vkquake_pak_size_extracted,
+					TINFL_FLAG_USING_NON_WRAPPING_OUTPUT_BUF);
+
+				if (TINFL_STATUS_DONE != decomp_status)
 					Sys_Error ("Error extracting embedded pack");
 			}
 			qboolean pak0_modified = com_modified;
