@@ -549,13 +549,13 @@ void Con_DWarning (const char *fmt, ...)
 		va_end (argptr);
 
 		Con_SafePrintf ("\x02Warning: ");
-		Con_Printf ("%s", msg);
+		Con_SafePrintf ("%s", msg);
 	}
 }
 
 /*
 ================
-Con_Warning -- johnfitz -- prints a warning to the console
+Con_Warning -- johnfitz -- prints a warning to the console. Is thread-safe.
 ================
 */
 void Con_Warning (const char *fmt, ...)
@@ -568,7 +568,7 @@ void Con_Warning (const char *fmt, ...)
 	va_end (argptr);
 
 	Con_SafePrintf ("\x02Warning: ");
-	Con_Printf ("%s", msg);
+	Con_SafePrintf ("%s", msg);
 }
 
 /*
