@@ -116,9 +116,9 @@ cvar_t scr_relcrosshairscale = {"scr_relcrosshairscale", "1", CVAR_ARCHIVE};
 cvar_t scr_relconscale = {"scr_relconscale", "1", CVAR_ARCHIVE};
 
 extern cvar_t crosshair;
+extern cvar_t crosshair_def;
 extern cvar_t r_tasks;
 extern cvar_t r_gpulightmapupdate;
-extern cvar_t r_showtris;
 extern cvar_t r_showbboxes;
 
 qboolean scr_initialized; // ready to draw
@@ -187,7 +187,7 @@ void SCR_CenterPrint (const char *str) // update centerprint data
 	}
 }
 
-void SCR_DrawCenterString (cb_context_t *cbx) // actually do the drawing
+static void SCR_DrawCenterString (cb_context_t *cbx) // actually do the drawing
 {
 	char *start;
 	int	  l;
@@ -211,15 +211,15 @@ void SCR_DrawCenterString (cb_context_t *cbx) // actually do the drawing
 	else
 		y = 48;
 	if (crosshair.value)
-		y -= 8;
+		y -= CHARACTER_SIZE;
 
 	do
 	{
 		// scan the width of the line
-		for (l = 0; l < 40; l++)
-			if (start[l] == '\n' || !start[l])
+		for (l = 0; start[l]; l++)
+			if (start[l] == '\n')
 				break;
-		x = (320 - l * 8) / 2; // johnfitz -- 320x200 coordinate system
+		x = (320 - l * CHARACTER_SIZE) / 2; // johnfitz -- 320x200 coordinate system
 		for (j = 0; j < l; j++, x += CHARACTER_SIZE)
 		{
 			Draw_Character (cbx, x, y, start[j]); // johnfitz -- stretch overlays
@@ -227,10 +227,8 @@ void SCR_DrawCenterString (cb_context_t *cbx) // actually do the drawing
 				return;
 		}
 
-		y += 8;
-
-		while (*start && *start != '\n')
-			start++;
+		y += CHARACTER_SIZE;
+		start += l;
 
 		if (!*start)
 			break;
@@ -238,7 +236,7 @@ void SCR_DrawCenterString (cb_context_t *cbx) // actually do the drawing
 	} while (1);
 }
 
-void SCR_CheckDrawCenterString (cb_context_t *cbx)
+static void SCR_CheckDrawCenterString (cb_context_t *cbx)
 {
 	if (scr_center_lines > scr_erase_lines)
 		scr_erase_lines = scr_center_lines;
@@ -319,7 +317,7 @@ Adapt a 4:3 horizontal FOV to the current screen size using the "Hor+" scaling:
 2.0 * atan(width / height * 3.0 / 4.0 * tan(fov_x / 2.0))
 ====================
 */
-float AdaptFovx (float fov_x, float width, float height)
+static float AdaptFovx (float fov_x, float width, float height)
 {
 	float a, x;
 
@@ -345,7 +343,7 @@ float AdaptFovx (float fov_x, float width, float height)
 CalcFovy
 ====================
 */
-float CalcFovy (float fov_x, float width, float height)
+static float CalcFovy (float fov_x, float width, float height)
 {
 	float a, x;
 
@@ -427,7 +425,7 @@ SCR_SizeUp_f
 Keybinding command
 =================
 */
-void SCR_SizeUp_f (void)
+static void SCR_SizeUp_f (void)
 {
 	Cvar_SetValueQuick (&scr_viewsize, scr_viewsize.value + 10);
 }
@@ -439,7 +437,7 @@ SCR_SizeDown_f
 Keybinding command
 =================
 */
-void SCR_SizeDown_f (void)
+static void SCR_SizeDown_f (void)
 {
 	float new_value = scr_viewsize.value - 10;
 	if (!scr_viewsize_allow_shrinking.value)
@@ -614,7 +612,7 @@ void SCR_Init (void)
 SCR_DrawFPS -- johnfitz
 ==============
 */
-void SCR_DrawFPS (cb_context_t *cbx)
+static void SCR_DrawFPS (cb_context_t *cbx)
 {
 	static double oldtime = 0;
 	static double lastfps = 0;
@@ -645,7 +643,7 @@ void SCR_DrawFPS (cb_context_t *cbx)
 		int	 x, y;
 		q_snprintf (st, sizeof (st), "%4.0f fps", lastfps);
 		x = 320 - (strlen (st) << 3);
-		y = 200 - 8;
+		y = 200 - CHARACTER_SIZE;
 		GL_SetCanvas (cbx, CANVAS_BOTTOMRIGHT);
 		Draw_String (cbx, x, y, st);
 	}
@@ -656,10 +654,10 @@ void SCR_DrawFPS (cb_context_t *cbx)
 SCR_DrawClock -- johnfitz
 ==============
 */
-void SCR_DrawClock (cb_context_t *cbx)
+static void SCR_DrawClock (cb_context_t *cbx)
 {
 	char			str[32];
-	int				y = 200 - 8;
+	int				y = 200 - CHARACTER_SIZE;
 	static qboolean shown_pause;
 	extern qboolean sb_showscores;
 
@@ -683,16 +681,16 @@ void SCR_DrawClock (cb_context_t *cbx)
 	GL_SetCanvas (cbx, CANVAS_BOTTOMRIGHT);
 
 	if (scr_showfps.value)
-		y -= 8; // make room for fps counter
+		y -= CHARACTER_SIZE; // make room for fps counter
 
 	if (scr_clock.value >= 2)
 	{
 		q_snprintf (str, sizeof (str), "%i/%i", cl.stats[STAT_MONSTERS], cl.stats[STAT_TOTALMONSTERS]);
 		Draw_String (cbx, 320 - (strlen (str) << 3), y, str);
-		y -= 8;
+		y -= CHARACTER_SIZE;
 		q_snprintf (str, sizeof (str), "%i/%i", cl.stats[STAT_SECRETS], cl.stats[STAT_TOTALSECRETS]);
 		Draw_String (cbx, 320 - (strlen (str) << 3), y, str);
-		y -= 8;
+		y -= CHARACTER_SIZE;
 	}
 
 	q_snprintf (str, sizeof (str), "%i:%02i", (int)cl.time / 60, (int)cl.time % 60);
@@ -701,7 +699,7 @@ void SCR_DrawClock (cb_context_t *cbx)
 	// show playback rate
 	if (cls.demoplayback && cls.demospeed != 1)
 	{
-		y -= 8;
+		y -= CHARACTER_SIZE;
 		q_snprintf (str, sizeof (str), "[%gx]", cls.demospeed);
 		if (cls.demospeed == 0)
 			q_snprintf (str, sizeof (str), "[paused]");
@@ -714,7 +712,7 @@ void SCR_DrawClock (cb_context_t *cbx)
 SCR_DrawDevStats
 ==============
 */
-void SCR_DrawDevStats (cb_context_t *cbx)
+static void SCR_DrawDevStats (cb_context_t *cbx)
 {
 	char str[40];
 	int	 y = 25 - 9; // 9=number of lines to print
@@ -725,34 +723,34 @@ void SCR_DrawDevStats (cb_context_t *cbx)
 
 	GL_SetCanvas (cbx, CANVAS_BOTTOMLEFT);
 
-	Draw_Fill (cbx, x, y * 8, 19 * 8, 9 * 8, 0, 0.5); // dark rectangle
+	Draw_Fill (cbx, x, y * CHARACTER_SIZE, 19 * CHARACTER_SIZE, 9 * CHARACTER_SIZE, 0, 0.5); // dark rectangle
 
 	q_snprintf (str, sizeof (str), "devstats |Curr Peak");
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "---------+---------");
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Edicts   |%4i %4i", dev_stats.edicts, dev_peakstats.edicts);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Packet   |%4i %4i", dev_stats.packetsize, dev_peakstats.packetsize);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Visedicts|%4i %4i", dev_stats.visedicts, dev_peakstats.visedicts);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Efrags   |%4i %4i", dev_stats.efrags, dev_peakstats.efrags);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Dlights  |%4i %4i", dev_stats.dlights, dev_peakstats.dlights);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Beams    |%4i %4i", dev_stats.beams, dev_peakstats.beams);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 
 	q_snprintf (str, sizeof (str), "Tempents |%4i %4i", dev_stats.tempents, dev_peakstats.tempents);
-	Draw_String (cbx, x, (y++) * 8 - x, str);
+	Draw_String (cbx, x, (y++) * CHARACTER_SIZE - x, str);
 }
 
 /*
@@ -760,7 +758,7 @@ void SCR_DrawDevStats (cb_context_t *cbx)
 SCR_DrawTurtle
 ==============
 */
-void SCR_DrawTurtle (cb_context_t *cbx)
+static void SCR_DrawTurtle (cb_context_t *cbx)
 {
 	static int count;
 
@@ -787,7 +785,7 @@ void SCR_DrawTurtle (cb_context_t *cbx)
 SCR_DrawNet
 ==============
 */
-void SCR_DrawNet (cb_context_t *cbx)
+static void SCR_DrawNet (cb_context_t *cbx)
 {
 	if (realtime - cl.last_received_message < 0.3)
 		return;
@@ -804,7 +802,7 @@ void SCR_DrawNet (cb_context_t *cbx)
 DrawPause
 ==============
 */
-void SCR_DrawPause (cb_context_t *cbx)
+static void SCR_DrawPause (cb_context_t *cbx)
 {
 	qpic_t *pic;
 
@@ -828,7 +826,7 @@ void SCR_DrawPause (cb_context_t *cbx)
 SCR_DrawLoading
 ==============
 */
-void SCR_DrawLoading (cb_context_t *cbx)
+static void SCR_DrawLoading (cb_context_t *cbx)
 {
 	qpic_t *pic;
 
@@ -846,16 +844,18 @@ void SCR_DrawLoading (cb_context_t *cbx)
 SCR_DrawCrosshair -- johnfitz
 ==============
 */
-void SCR_DrawCrosshair (cb_context_t *cbx)
+static void SCR_DrawCrosshair (cb_context_t *cbx)
 {
 	if (!crosshair.value || scr_viewsize.value >= 130)
 		return;
 
 	GL_SetCanvas (cbx, CANVAS_CROSSHAIR);
-	if (crosshair.value >= 2.0f)
-		Draw_Character (cbx, -2, -5, '.'); // 0,0 is center of viewport
-	else
-		Draw_Character (cbx, -4, -4, '+'); // 0,0 is center of viewport
+
+	if (crosshair.value)
+	{
+		crosshair_t current = M_GetCrosshairDef (crosshair_def.value);
+		Draw_Character (cbx, current.viewport_x_offset, current.viewport_y_offset, current.crosshair_char); // 0,0 is center of viewport
+	}
 }
 
 //=============================================================================
@@ -865,7 +865,7 @@ void SCR_DrawCrosshair (cb_context_t *cbx)
 SCR_SetUpToDrawConsole
 ==================
 */
-void SCR_SetUpToDrawConsole (void)
+static void SCR_SetUpToDrawConsole (void)
 {
 	// johnfitz -- let's hack away the problem of slow console when host_timescale is <0
 	extern cvar_t host_timescale;
@@ -920,7 +920,7 @@ void SCR_SetUpToDrawConsole (void)
 SCR_DrawConsole
 ==================
 */
-void SCR_DrawConsole (cb_context_t *cbx)
+static void SCR_DrawConsole (cb_context_t *cbx)
 {
 	if (scr_con_current)
 	{
@@ -981,7 +981,7 @@ void SCR_EndLoadingPlaque (void)
 const char *scr_notifystring;
 qboolean	scr_drawdialog;
 
-void SCR_DrawNotifyString (cb_context_t *cbx)
+static void SCR_DrawNotifyString (cb_context_t *cbx)
 {
 	const char *start;
 	int			l;
@@ -997,17 +997,15 @@ void SCR_DrawNotifyString (cb_context_t *cbx)
 	do
 	{
 		// scan the width of the line
-		for (l = 0; l < 40; l++)
-			if (start[l] == '\n' || !start[l])
+		for (l = 0; start[l]; l++)
+			if (start[l] == '\n')
 				break;
-		x = (320 - l * 8) / 2; // johnfitz -- stretched overlays
+		x = (320 - l * CHARACTER_SIZE) / 2; // johnfitz -- 320x200 coordinate system
 		for (j = 0; j < l; j++, x += CHARACTER_SIZE)
 			Draw_Character (cbx, x, y, start[j]);
 
-		y += 8;
-
-		while (*start && *start != '\n')
-			start++;
+		y += CHARACTER_SIZE;
+		start += l;
 
 		if (!*start)
 			break;
