@@ -979,7 +979,23 @@ static void TexMgr_LoadImage32 (gltexture_t *glt, unsigned *data)
 			mipheight = maxsize;
 		}
 	}
+	// has alpha detection :
+	if (data && glt->source_format == SRC_RGBA && !(glt->flags & TEXPREF_ALPHAPIXELS))
+	{
+		int	  num_pixels = glt->width * glt->height;
+		byte *pixel_data = (byte *)data;
 
+		for (int i = 0; i < num_pixels; i++)
+		{
+			if (pixel_data[i * 4 + 3] != 255)
+			{
+				glt->flags |= TEXPREF_ALPHA;
+				glt->flags |= TEXPREF_ALPHAPIXELS;
+				break;
+			}
+		}
+	}
+	// mipmap generation:
 	if ((int)glt->width != mipwidth || (int)glt->height != mipheight)
 	{
 		if (is_cube)
@@ -1411,6 +1427,7 @@ gltexture_t *TexMgr_LoadImage (
 	// copy data
 	glt->owner = owner;
 	q_strlcpy (glt->name, name, sizeof (glt->name));
+	glt->path_id = (glt->owner ? glt->owner->path_id : 0);
 	glt->width = width;
 	glt->height = height;
 	glt->flags = flags;
@@ -1492,7 +1509,8 @@ void TexMgr_ReloadImage (gltexture_t *glt, int shirt, int pants)
 	}
 	else if (glt->source_file[0] && !glt->source_offset)
 	{
-		allocated = data = Image_LoadImage (glt->source_file, (int *)&glt->source_width, (int *)&glt->source_height, &glt->source_format); // simple file
+		allocated = data =
+			Image_LoadImage (glt->source_file, (int *)&glt->source_width, (int *)&glt->source_height, &glt->source_format, glt->path_id); // simple file
 	}
 	else if (!glt->source_file[0] && glt->source_offset)
 	{
