@@ -883,12 +883,12 @@ For debugging, prints all the entities in the current server
 */
 void ED_PrintEdicts (void)
 {
-	int free_edicts_count = 0;
-	int free_list_count = 0;
-
 	if (!sv.active)
 		return;
 
+	int free_edicts_count = 0;
+	int free_list_count = 0;
+
 	PR_SwitchQCVM (&sv.qcvm);
 
 	// display the non-free ones first
@@ -922,6 +922,11 @@ void ED_PrintEdicts (void)
 
 	Con_Printf ("Total: %i entities\n", qcvm->num_edicts);
 
+	if (free_list_count != free_edicts_count)
+	{
+		Con_Warning ("free_list_count:%i is not equal to free_edicts_count:%i\n", free_list_count, free_edicts_count);
+	}
+
 	PR_SwitchQCVM (NULL);
 }
 
