@@ -105,15 +105,69 @@ static void GL_DrawAliasFrame (
 	qboolean alphatest, vec3_t shadevector, vec3_t lightcolor, int showtris)
 {
 	vulkan_pipeline_t pipeline;
-	const int		  pipeline_index = (showtris == 0) ? (((entity_alpha >= 1.0f) ? 0 : 2) + (alphatest ? 1 : 0)) : (3 + CLAMP (1, showtris, 2));
+
+	int pipeline_index = 0;
+
+	// only enable alpha management if entity have alpha or the surface texture has effective
+	// non-opaque pixels:
+	const bool has_alpha = (entity_alpha < 1.0f) || (tx->flags & TEXPREF_ALPHAPIXELS);
+
+	// was : pipeline_index = (showtris == 0) ? (((entity_alpha >= 1.0f) ? 0 : 2) + (alphatest ? 1 : 0)) : (3 + CLAMP (1, showtris, 2));
+	//  decomposed below for clarity:
+	if (showtris == 0)
+	{
+		// depthBiasEnable = VK_FALSE;
+		// depthTestEnable = VK_TRUE;
+		//
+		//  has_alpha = none, alphatest = 0 ? => 0
+		//  depthWriteEnable = VK_TRUE;
+		//  blendEnable = VK_FALSE;
+		//
+		//  has_alpha = none, alphatest = 1 ? => 1
+		//  alias_alphatest_frag_module ON
+		//  depthWriteEnable = VK_TRUE;
+		//  blendEnable = VK_FALSE;
+		//
+		//  has_alpha = yes, alphatest = 0 ?  => 2
+		//  depthWriteEnable = VK_TRUE => VK_FALSE;
+		//  blendEnable = VK_FALSE => VK_TRUE;
+		//
+		//  has_alpha = yes, alphatest = 1 ?  => 3
+		//  alias_alphatest_frag_module ON
+		//  depthWriteEnable = VK_FALSE;
+		//  blendEnable = VK_TRUE;
+		pipeline_index = ((has_alpha ? 2 : 0) + (alphatest ? 1 : 0));
+	}
+	else
+	{
+		// polygonMode = VK_POLYGON_MODE_LINE;
+		// blendEnable = VK_FALSE;
+		//
+		//  showtris == 1
+		//  depthTestEnable = VK_FALSE;
+		//  depthWriteEnable = VK_FALSE;
+		//  depthBiasEnable = VK_FALSE;
+		//
+		//  showtris >= 2
+		//  depthTestEnable = VK_FALSE => VK_TRUE;
+		//  depthWriteEnable = VK_FALSE;
+		//  depthBiasEnable = VK_FALSE => VK_TRUE;
+		pipeline_index = (3 + CLAMP (1, showtris, 2));
+	}
+
 	switch (paliashdr->poseverttype)
 	{
 	case PV_MD5:
 		pipeline = vulkan_globals.md5_pipelines[pipeline_index];
 		break;
-	default:
+	case PV_QUAKE1:
 		pipeline = vulkan_globals.alias_pipelines[pipeline_index];
 		break;
+	case PV_QUAKE3:
+		pipeline = vulkan_globals.alias_pipelines[pipeline_index];
+		break;
+	default:
+		pipeline = vulkan_globals.alias_pipelines[pipeline_index];
 	}
 
 	R_BindPipeline (cbx, VK_PIPELINE_BIND_POINT_GRAPHICS, pipeline);
@@ -128,6 +182,7 @@ static void GL_DrawAliasFrame (
 	switch (paliashdr->poseverttype)
 	{
 	case PV_QUAKE1:
+	case PV_QUAKE3:
 	{
 		VkBuffer		uniform_buffer;
 		uint32_t		uniform_offset;
@@ -139,8 +194,13 @@ static void GL_DrawAliasFrame (
 		ubo->blend_factor = blend;
 		memcpy (ubo->light_color, lightcolor, 3 * sizeof (float));
 		ubo->flags = (fb != NULL) ? 0x1 : 0x0;
+
 		if (r_fullbright_cheatsafe || (r_lightmap_cheatsafe && r_fullbright.value))
 			ubo->flags |= 0x2;
+
+		if (paliashdr->poseverttype == PV_QUAKE3)
+			ubo->flags |= 0x4;
+
 		ubo->entalpha = entity_alpha;
 
 		VkDescriptorSet descriptor_sets[3] = {tx->descriptor_set, (fb != NULL) ? fb->descriptor_set : tx->descriptor_set, ubo_set};
@@ -183,10 +243,12 @@ static void GL_DrawAliasFrame (
 		vulkan_globals.vk_cmd_bind_vertex_buffers (cbx->cb, 0, 1, vertex_buffers, vertex_offsets);
 		vulkan_globals.vk_cmd_bind_index_buffer (cbx->cb, paliashdr->index_buffer, 0, VK_INDEX_TYPE_UINT16);
 
-		// paliashdr->vertex_buffer contains all the indices of its nextsurface, so we draw paliashdr->total_numindexes.
-		vulkan_globals.vk_cmd_draw_indexed (cbx->cb, paliashdr->total_numindexes, 1, 0, 0, 0);
+		//
+		vulkan_globals.vk_cmd_draw_indexed (cbx->cb, paliashdr->numindexes, 1, 0, 0, 0);
 		break;
 	}
+	default:
+		assert (false);
 	}
 }
 
@@ -434,12 +496,14 @@ void R_DrawAliasModel (cb_context_t *cbx, entity_t *e, int *aliaspolys)
 	int			 anim, skinnum = e->skinnum;
 	gltexture_t *tx, *fb;
 	lerpdata_t	 lerpdata;
-	qboolean	 alphatest = !!(e->model->flags & MF_HOLEY);
 
 	//
 	// setup pose/lerp data -- do it first so we don't miss updates due to culling
 	//
 	paliashdr = (aliashdr_t *)Mod_Extradata_CheckSkin (e->model, skinnum);
+
+	qboolean alphatest = !!(e->model->flags & MF_HOLEY);
+
 	R_SetupAliasFrame (e, paliashdr, e->frame, &lerpdata);
 	R_SetupEntityTransform (e, &lerpdata);
 
@@ -485,54 +549,65 @@ void R_DrawAliasModel (cb_context_t *cbx, entity_t *e, int *aliaspolys)
 	//
 	// set up lighting
 	//
-	for (const aliashdr_t *hdr = paliashdr; hdr != NULL; hdr = hdr->nextsurface)
-	{
-		*aliaspolys += hdr->numtris;
-	}
-
 	vec3_t shadevector, lightcolor;
 	R_SetupAliasLighting (e, &shadevector, &lightcolor);
 
-	//
-	// set up textures
-	//
-	anim = (int)(cl.time * 10) & 3;
-	if ((skinnum >= paliashdr->numskins) || (skinnum < 0))
+	// Draw each surface of the model independently:
+	for (aliashdr_t *hdr = paliashdr; hdr != NULL; hdr = hdr->nextsurface)
 	{
-		Con_DPrintf ("R_DrawAliasModel: no such skin # %d for '%s'\n", skinnum, e->model->name);
-		// ericw -- display skin 0 for winquake compatibility
-		skinnum = 0;
-	}
-	tx = paliashdr->gltextures[skinnum][anim];
-	fb = paliashdr->fbtextures[skinnum][anim];
-	if (e->colormap != vid.colormap && !gl_nocolors.value)
-		if ((uintptr_t)e >= (uintptr_t)&cl.entities[1] && (uintptr_t)e <= (uintptr_t)&cl.entities[cl.maxclients] && playertextures[e - cl.entities - 1])
-			tx = playertextures[e - cl.entities - 1];
-	if (!gl_fullbrights.value)
-		fb = NULL;
-
-	if (r_fullbright_cheatsafe)
-	{
-		lightcolor[0] = 0.5f;
-		lightcolor[1] = 0.5f;
-		lightcolor[2] = 0.5f;
-	}
-	if (r_lightmap_cheatsafe)
-	{
-		tx = greytexture;
-		fb = NULL;
-		if (r_fullbright.value)
+		//
+		// set up textures
+		//
+		anim = (int)(cl.time * 10) & 3;
+		if ((skinnum >= hdr->numskins) || (skinnum < 0))
 		{
-			lightcolor[0] = 1.0f;
-			lightcolor[1] = 1.0f;
-			lightcolor[2] = 1.0f;
+			Con_DPrintf ("R_DrawAliasModel: no such skin # %d for '%s'\n", skinnum, e->model->name);
+			// ericw -- display skin 0 for winquake compatibility
+			skinnum = 0;
 		}
-	}
+		tx = hdr->gltextures[skinnum][anim];
+		fb = hdr->fbtextures[skinnum][anim];
 
-	//
-	// draw it
-	//
-	GL_DrawAliasFrame (cbx, e, paliashdr, lerpdata, tx, fb, model_matrix, entalpha, alphatest, shadevector, lightcolor, false);
+		if (e->colormap != vid.colormap && !gl_nocolors.value)
+			if ((uintptr_t)e >= (uintptr_t)&cl.entities[1] && (uintptr_t)e <= (uintptr_t)&cl.entities[cl.maxclients] && playertextures[e - cl.entities - 1])
+				tx = playertextures[e - cl.entities - 1];
+
+		// if there are no texture, force the grey one. (a.k.a lightmap).
+		if (tx == NULL)
+		{
+			tx = greytexture;
+			fb = NULL;
+		}
+
+		if (!gl_fullbrights.value)
+			fb = NULL;
+
+		if (r_fullbright_cheatsafe)
+		{
+			lightcolor[0] = 0.5f;
+			lightcolor[1] = 0.5f;
+			lightcolor[2] = 0.5f;
+		}
+		if (r_lightmap_cheatsafe)
+		{
+			tx = greytexture;
+			fb = NULL;
+			if (r_fullbright.value)
+			{
+				lightcolor[0] = 1.0f;
+				lightcolor[1] = 1.0f;
+				lightcolor[2] = 1.0f;
+			}
+		}
+
+		//
+		// draw it
+		//
+		GL_DrawAliasFrame (cbx, e, hdr, lerpdata, tx, fb, model_matrix, entalpha, alphatest, shadevector, lightcolor, false);
+
+		// update polycounts
+		*aliaspolys += hdr->numtris;
+	} // e for each surface
 }
 
 // johnfitz -- values for shadow matrix
@@ -590,5 +665,9 @@ void R_DrawAliasModel_ShowTris (cb_context_t *cbx, entity_t *e)
 
 	vec3_t shadevector = {0.0f, 0.0f, 0.0f};
 	vec3_t lightcolor = {0.0f, 0.0f, 0.0f};
-	GL_DrawAliasFrame (cbx, e, paliashdr, lerpdata, nulltexture, nulltexture, model_matrix, 0.0f, false, shadevector, lightcolor, r_showtris.value);
+	// Draw each surface of the model independently:
+	for (aliashdr_t *hdr = paliashdr; hdr != NULL; hdr = hdr->nextsurface)
+	{
+		GL_DrawAliasFrame (cbx, e, hdr, lerpdata, nulltexture, nulltexture, model_matrix, 0.0f, false, shadevector, lightcolor, r_showtris.value);
+	}
 }
