@@ -38,6 +38,11 @@ extern cvar_t vid_palettize;
 
 cvar_t r_parallelmark = {"r_parallelmark", "1", CVAR_NONE};
 
+// vso - in some cases, R_DrawTextureChains_Water oprimization
+// make some surfaces not rendered. Since this optimization does not seem
+// to actually impact performance disable it by default for now.
+cvar_t r_drawwater_fast = {"r_drawwater_fast", "0", CVAR_ARCHIVE};
+
 byte *SV_FatPVS (vec3_t org, qmodel_t *worldmodel);
 
 extern VkBuffer bmodel_vertex_buffer;
@@ -364,6 +369,8 @@ void R_MarkVisSurfacesSIMD (qboolean *use_tasks)
 	uint32_t	*surfvis = (uint32_t *)cl.worldmodel->surfvis;
 	soa_aabb_t	*leafbounds = cl.worldmodel->soa_leafbounds;
 
+	int current_combined_dep_index = INT_MAX;
+
 	// iterate through leaves, marking surfaces
 	for (i = 0; i < numleafs; i += 32)
 	{
@@ -387,8 +394,12 @@ void R_MarkVisSurfacesSIMD (qboolean *use_tasks)
 					unsigned int index = marksurfaces[k];
 					surfvis[index / 32] |= 1u << (index % 32);
 				}
-				if (indirect)
+
+				if (indirect && current_combined_dep_index != leaf->combined_deps)
+				{
 					R_MarkDeps (leaf->combined_deps, 0);
+					current_combined_dep_index = leaf->combined_deps;
+				}
 			}
 
 			// add static models
@@ -421,7 +432,7 @@ void R_MarkVisSurfacesSIMD (qboolean *use_tasks)
 			else if (surf->lightmaptexturenum >= 0)
 				lightmaps[surf->lightmaptexturenum].modified[0] |= surf->styles_bitmap;
 			if (surf->texinfo->texture->warpimage)
-				Atomic_StoreUInt32 (&surf->texinfo->texture->update_warp, true);
+				Atomic_StoreUInt32_Relaxed (&surf->texinfo->texture->update_warp, true);
 		}
 	}
 
@@ -452,6 +463,7 @@ void R_MarkLeafsSIMD (int index, void *unused)
 
 	unsigned int current_surfvis_index_written = 0;
 	uint32_t	 current_surfvis_written = 0;
+	int			 current_combined_dep_index = INT_MAX;
 
 	while (mask_iter != 0)
 	{
@@ -470,15 +482,18 @@ void R_MarkLeafsSIMD (int index, void *unused)
 
 				if (surf_index / 32 != current_surfvis_index_written)
 				{
-					Atomic_OrUInt32 (&surfvis[current_surfvis_index_written], current_surfvis_written);
+					Atomic_OrUInt32_Relaxed (&surfvis[current_surfvis_index_written], current_surfvis_written);
 					current_surfvis_index_written = surf_index / 32;
 					current_surfvis_written = 0;
 				}
 				current_surfvis_written |= 1u << (surf_index % 32);
 			}
 
-			if (indirect)
+			if (indirect && current_combined_dep_index != leaf->combined_deps)
+			{
 				R_MarkDeps (leaf->combined_deps, Tasks_GetWorkerIndex ());
+				current_combined_dep_index = leaf->combined_deps;
+			}
 		}
 		const uint32_t bit_mask = ~(1u << i);
 		if (!leaf->efrags)
@@ -487,8 +502,8 @@ void R_MarkLeafsSIMD (int index, void *unused)
 		}
 		mask_iter &= bit_mask;
 	}
-
-	Atomic_OrUInt32 (&surfvis[current_surfvis_index_written], current_surfvis_written);
+	if (current_surfvis_written != 0)
+		Atomic_OrUInt32_Relaxed (&surfvis[current_surfvis_index_written], current_surfvis_written);
 }
 
 /*
@@ -517,7 +532,7 @@ void R_BackfaceCullSurfacesSIMD (int index, void *unused)
 		if (surf->lightmaptexturenum >= 0)
 			lightmaps[surf->lightmaptexturenum].modified[worker_index] |= surf->styles_bitmap;
 		if (surf->texinfo->texture->warpimage)
-			Atomic_StoreUInt32 (&surf->texinfo->texture->update_warp, true);
+			Atomic_StoreUInt32_Relaxed (&surf->texinfo->texture->update_warp, true);
 
 		const uint32_t bit_mask = ~(1u << i);
 		mask_iter &= bit_mask;
@@ -656,6 +671,7 @@ void R_MarkLeafsParallel (int index, void *unused)
 
 	unsigned int current_surfvis_index_written = 0;
 	uint32_t	 current_surfvis_written = 0;
+	int			 current_combined_dep_index = INT_MAX;
 
 	while (mask_iter != 0)
 	{
@@ -681,18 +697,22 @@ void R_MarkLeafsParallel (int index, void *unused)
 
 				if (surf_index / 32 != current_surfvis_index_written)
 				{
-					Atomic_OrUInt32 (&surfvis[current_surfvis_index_written], current_surfvis_written);
+					Atomic_OrUInt32_Relaxed (&surfvis[current_surfvis_index_written], current_surfvis_written);
 					current_surfvis_index_written = surf_index / 32;
 					current_surfvis_written = 0;
 				}
 				current_surfvis_written |= 1u << (surf_index % 32);
 			}
-			if (indirect)
+
+			if (indirect && current_combined_dep_index != leaf->combined_deps)
+			{
 				R_MarkDeps (leaf->combined_deps, Tasks_GetWorkerIndex ());
+				current_combined_dep_index = leaf->combined_deps;
+			}
 		}
 	}
-
-	Atomic_OrUInt32 (&surfvis[current_surfvis_index_written], current_surfvis_written);
+	if (current_surfvis_written != 0)
+		Atomic_OrUInt32_Relaxed (&surfvis[current_surfvis_index_written], current_surfvis_written);
 }
 
 /*
@@ -725,7 +745,7 @@ void R_BackfaceCullSurfacesParallel (int index, void *unused)
 			if (surf->lightmaptexturenum >= 0)
 				lightmaps[surf->lightmaptexturenum].modified[worker_index] |= surf->styles_bitmap;
 			if (surf->texinfo->texture->warpimage)
-				Atomic_StoreUInt32 (&surf->texinfo->texture->update_warp, true);
+				Atomic_StoreUInt32_Relaxed (&surf->texinfo->texture->update_warp, true);
 		}
 	}
 }
@@ -744,6 +764,8 @@ void R_MarkVisSurfaces (qboolean *use_tasks)
 	uint32_t   *vis = (uint32_t *)mark_surfaces_state.vis;
 	uint32_t   *surfvis = (uint32_t *)cl.worldmodel->surfvis;
 
+	int current_combined_dep_index = INT_MAX;
+
 	leaf = &cl.worldmodel->leafs[1];
 	for (i = 0; i < cl.worldmodel->numleafs; i++, leaf++)
 	{
@@ -754,8 +776,12 @@ void R_MarkVisSurfaces (qboolean *use_tasks)
 
 			if (r_drawworld_cheatsafe && (leaf->contents != CONTENTS_SKY || r_oldskyleaf.value))
 			{
-				if (indirect)
+				if (indirect && current_combined_dep_index != leaf->combined_deps)
+				{
 					R_MarkDeps (leaf->combined_deps, 0);
+					current_combined_dep_index = leaf->combined_deps;
+				}
+
 				for (j = 0; j < leaf->nummarksurfaces; j++)
 				{
 					if (indirect)
@@ -777,7 +803,7 @@ void R_MarkVisSurfaces (qboolean *use_tasks)
 							else if (surf->lightmaptexturenum >= 0)
 								lightmaps[surf->lightmaptexturenum].modified[0] |= surf->styles_bitmap;
 							if (surf->texinfo->texture->warpimage)
-								Atomic_StoreUInt32 (&surf->texinfo->texture->update_warp, true);
+								Atomic_StoreUInt32_Relaxed (&surf->texinfo->texture->update_warp, true);
 						}
 					}
 				}
@@ -878,8 +904,10 @@ static void R_MarkSurfacesPrepare (void *unused)
 	}
 	else
 #endif
+	{
 		if (r_parallelmark.value || indirect)
-		memset (cl.worldmodel->surfvis, 0, (cl.worldmodel->numsurfaces + 31) / 8);
+			memset (cl.worldmodel->surfvis, 0, (cl.worldmodel->numsurfaces + 31) / 8);
+	}
 }
 
 /*
@@ -1154,8 +1182,21 @@ void R_DrawTextureChains_Water (cb_context_t *cbx, qmodel_t *model, entity_t *en
 		const float	   alpha = GL_WaterAlphaForEntitySurface (ent, t->texturechains[chain]);
 		const qboolean alpha_blend = alpha < 1.0f;
 
-		if (((opaque_only && alpha_blend) || (transparent_only && !alpha_blend)) && (!r_lightmap_cheatsafe || !indirect))
-			continue;
+		// vso - water-like surfaces are in some cases rendered incorrectly,
+		// disabling this path solves the issue.
+		if (r_drawwater_fast.value > 0.0f)
+		{
+			if (alpha_blend)
+			{
+				if (opaque_only && (!r_lightmap_cheatsafe || !indirect))
+					continue;
+			}
+			else
+			{
+				if (transparent_only && (!r_lightmap_cheatsafe || !indirect))
+					continue;
+			}
+		}
 
 		gltexture_t *gl_texture = t->warpimage;
 		if (!r_lightmap_cheatsafe)
