@@ -818,7 +818,7 @@ static void SVFTE_WriteEntitiesToClient (client_t *client, sizebuf_t *msg, size_
 /*
 SV_BuildEntityState
 copies edict state into a more compact entity_state_t with all the extension fields etc sorted out and neatened up for network precision.
-note: ignores viewmodelforclient and other client-specific stuff.
+note: ignores  like nodrawtoclient / drawonlytoclient and other client-specific stuff.
 */
 void SV_BuildEntityState (edict_t *ent, entity_state_t *state)
 {
@@ -882,7 +882,9 @@ static void SVFTE_BuildSnapshotForClient (client_t *client)
 	edict_t		 *ent, *parent;
 	unsigned int  maxentities = client->limit_entities;
 	edict_t		 *clent = client->edict;
+	eval_t		 *val;
 	unsigned char eflags;
+	int			  proged = EDICT_TO_PROG (clent);
 
 	struct entity_num_state_s *ents = snapshot_entstate;
 	size_t					   numents = 0;
@@ -909,31 +911,35 @@ static void SVFTE_BuildSnapshotForClient (client_t *client)
 				continue;
 			}
 
+			// attached entities should use the pvs of the parent rather than the child (because the child will typically be bugging out around '0 0 0', so
+			// won't be useful)
+			parent = ent;
+			if (parent->num_leafs)
 			{
-				// attached entities should use the pvs of the parent rather than the child (because the child will typically be bugging out around '0 0 0', so
-				// won't be useful)
-				parent = ent;
-				if (parent->num_leafs)
-				{
-					// ignore if not touching a PV leaf
-					for (i = 0; i < parent->num_leafs; i++)
-						if (pvs[parent->leafnums[i] >> 3] & (1 << (parent->leafnums[i] & 7)))
-							break;
+				// ignore if not touching a PV leaf
+				for (i = 0; i < parent->num_leafs; i++)
+					if (pvs[parent->leafnums[i] >> 3] & (1 << (parent->leafnums[i] & 7)))
+						break;
 
-					// ericw -- added ent->num_leafs < MAX_ENT_LEAFS condition.
-					//
-					// if ent->num_leafs == MAX_ENT_LEAFS, the ent is visible from too many leafs
-					// for us to say whether it's in the PVS, so don't try to vis cull it.
-					// this commonly happens with rotators, because they often have huge bboxes
-					// spanning the entire map, or really tall lifts, etc.
-					if (i == parent->num_leafs && parent->num_leafs < MAX_ENT_LEAFS)
-						goto invisible; // not visible
-				}
+				// ericw -- added ent->num_leafs < MAX_ENT_LEAFS condition.
+				//
+				// if ent->num_leafs == MAX_ENT_LEAFS, the ent is visible from too many leafs
+				// for us to say whether it's in the PVS, so don't try to vis cull it.
+				// this commonly happens with rotators, because they often have huge bboxes
+				// spanning the entire map, or really tall lifts, etc.
+				if (i == parent->num_leafs && parent->num_leafs < MAX_ENT_LEAFS)
+					goto invisible; // not visible
 			}
 		}
 
-		// okay, we care about this entity.
+		val = GetEdictFieldValue (ent, qcvm->extfields.nodrawtoclient);
+		if (val && val->edict == proged)
+			goto invisible;
+		val = GetEdictFieldValue (ent, qcvm->extfields.drawonlytoclient);
+		if (val && val->edict && val->edict != proged)
+			goto invisible;
 
+		// okay, we care about this entity.
 		if (numents == maxents)
 		{
 			maxents += 64;
@@ -1146,6 +1152,10 @@ void SV_Init (void)
 	extern cvar_t sv_aim;
 	extern cvar_t sv_altnoclip; // johnfitz
 
+	// FTE optimized world geometry checks
+	extern cvar_t sv_fte_recursivehullckeck;
+	extern cvar_t sv_fte_createareanode;
+
 	Cvar_RegisterVariable (&sv_maxvelocity);
 	Cvar_RegisterVariable (&sv_gravity);
 	Cvar_RegisterVariable (&sv_friction);
@@ -1169,6 +1179,9 @@ void SV_Init (void)
 	Cvar_RegisterVariable (&sv_netsort);
 	Cvar_RegisterVariable (&sv_smoothplatformlerps);
 
+	Cvar_RegisterVariable (&sv_fte_recursivehullckeck);
+	Cvar_RegisterVariable (&sv_fte_createareanode);
+
 	Cmd_AddCommand ("pext", SV_Pext_f);
 	Cmd_AddCommand ("sv_protocol", &SV_Protocol_f); // johnfitz
 
@@ -1243,7 +1256,7 @@ weapon, feet, etc.
 
 Channel 0 is an auto-allocate channel, the others override anything
 allready running on that entity/channel pair.
-
+volume is in 0-255.
 An attenuation of 0 will play full volume everywhere in the level.
 Larger attenuations will drop off.  (max 4 attenuation)
 
@@ -1948,6 +1961,16 @@ void SV_WriteEntitiesToClient (client_t *client, sizebuf_t *msg, size_t overflow
 	{
 		if (ent != clent) // clent already added before the loop
 		{
+			// hide if the current client is specified
+			val = GetEdictFieldValue (ent, qcvm->extfields.nodrawtoclient);
+			if (val && val->edict == EDICT_TO_PROG (client))
+				continue;
+
+			// hide if the current client is not specified
+			val = GetEdictFieldValue (ent, qcvm->extfields.drawonlytoclient);
+			if (val && val->edict && val->edict != EDICT_TO_PROG (client))
+				continue;
+
 			// ignore ents without visible models
 			if (!ent->v.modelindex || !(model = PR_GetString (ent->v.model))[0])
 				continue;
@@ -2484,8 +2507,10 @@ SV_SendClientDatagram
 */
 qboolean SV_SendClientDatagram (client_t *client)
 {
-	byte	  buf[MAX_DATAGRAM + 1000];
-	sizebuf_t msg;
+	// made static to prevent too big stack usage.
+	// fine as a temporary because only called from the main thread.
+	static byte buf[MAX_DATAGRAM + 1000];
+	sizebuf_t	msg;
 
 	if (!client->netconnection)
 	{
