@@ -18,10 +18,22 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 // tasks.c -- parallel task system
-
+#include "arch_def.h"
 #include "tasks.h"
 #include "atomics.h"
 #include "quakedef.h"
+#include "q_ctype.h"
+
+// clang-format off
+#if defined(_WIN32)
+  #ifndef WIN32_LEAN_AND_MEAN
+    #define WIN32_LEAN_AND_MEAN
+  #endif
+  #include <windows.h>
+#elif defined(PLATFORM_UNIX) && !defined(PLATFORM_OSX) && !defined(PLATFORM_BSD) && !defined(TASK_AFFINITY_NOT_AVAILABLE)
+  #include <sched.h>
+  #include <pthread.h>
+#endif
 
 #if defined(USE_HELGRIND)
 #include "valgrind/helgrind.h"
@@ -40,6 +52,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 	} while (false)
 #endif
 
+// clang-format on
+
 #define NUM_INDEX_BITS		 8
 #define MAX_PENDING_TASKS	 (1u << NUM_INDEX_BITS)
 #define MAX_EXECUTABLE_TASKS 256
@@ -92,7 +106,6 @@ typedef struct
 } task_counter_t;
 
 static int					 num_workers = 0;
-static SDL_Thread		   **worker_threads;
 static task_t				 tasks[MAX_PENDING_TASKS];
 static task_queue_t			*free_task_queue;
 static task_queue_t			*executable_task_queue;
@@ -101,6 +114,11 @@ static uint8_t				 steal_worker_indices[TASKS_MAX_WORKERS * 2];
 static THREAD_LOCAL qboolean is_worker = false;
 static THREAD_LOCAL int		 tl_worker_index;
 
+COMPILE_TIME_ASSERT (steal_worker_indices, TASKS_MAX_WORKERS * 2 < UINT8_MAX);
+
+static int pinned_workers_core_ids[TASKS_MAX_WORKERS];
+static int num_pinned_workers = 0;
+
 /*
 ====================
 IndexedTaskCounterIndex
@@ -136,7 +154,7 @@ static inline uint64_t EpochFromTaskHandle (task_handle_t handle)
 CreateTaskHandle
 ====================
 */
-static inline task_handle_t CreateTaskHandle (uint32_t index, int epoch)
+static inline task_handle_t CreateTaskHandle (uint32_t index, uint64_t epoch)
 {
 	return (task_handle_t)index | ((task_handle_t)epoch << NUM_INDEX_BITS);
 }
@@ -232,7 +250,7 @@ static inline void TaskQueuePush (task_queue_t *queue, uint32_t task_index)
 /*
 ====================
 TaskQueuePop
-====================a
+====================
 */
 static inline uint32_t TaskQueuePop (task_queue_t *queue)
 {
@@ -277,6 +295,56 @@ static inline void Task_ExecuteIndexed (int worker_index, task_t *task, uint32_t
 	}
 }
 
+static bool Task_Pin_Current_Worker (int pinned_index)
+{
+#if defined(_WIN32)
+	// valid for both MSVC and MINGW
+	//  Open the thread with necessary access rights
+	DWORD  dwThreadId = GetCurrentThreadId ();
+	HANDLE hThreadAccess = OpenThread (THREAD_SET_INFORMATION | THREAD_QUERY_INFORMATION, FALSE, dwThreadId);
+	if (hThreadAccess == NULL)
+	{
+		return false;
+	}
+
+	// Define the processor affinity mask, fold beyond DWORD_PTR bit size...
+	// should allow setting to 32 different cores on 32 bit and 64 different on 64 bits, should be enough for anybody....
+	DWORD_PTR mask = ((DWORD_PTR)1 << ((DWORD_PTR)pinned_workers_core_ids[pinned_index] % (sizeof (DWORD_PTR) * 8)));
+
+	// Set the thread affinity
+	DWORD_PTR prevAffinityMask = SetThreadAffinityMask (hThreadAccess, mask);
+	if (prevAffinityMask == 0)
+	{
+		CloseHandle (hThreadAccess);
+		return false;
+	}
+
+	// Close the thread handle
+	CloseHandle (hThreadAccess);
+
+	return true;
+
+#elif defined(PLATFORM_UNIX) && !defined(PLATFORM_OSX) && !defined(PLATFORM_BSD) && !defined(TASK_AFFINITY_NOT_AVAILABLE)
+#pragma message("Info : Pinned tasks support for *Nix enabled using pthread_setaffinity_np()...")
+
+	// valid for *Nix with GNU pthread extension pthread_setaffinity_np()
+	//  which apparently is not available on OSX so skip it in that case.
+	cpu_set_t cpuset;
+	CPU_ZERO (&cpuset);
+	CPU_SET (pinned_workers_core_ids[pinned_index], &cpuset);
+
+	pthread_t current_thread = pthread_self ();
+	if (pthread_setaffinity_np (current_thread, sizeof (cpu_set_t), &cpuset) != 0)
+	{
+		return false;
+	}
+
+	return true;
+
+#endif
+	return false;
+}
+
 /*
 ====================
 Task_Worker
@@ -288,6 +356,19 @@ static int Task_Worker (void *data)
 
 	const int worker_index = (intptr_t)data;
 	tl_worker_index = worker_index;
+
+	// try to pin workers on different cores, if set
+	if (num_pinned_workers)
+	{
+		assert (worker_index < num_pinned_workers);
+		assert (num_pinned_workers == num_workers);
+
+		if (!Task_Pin_Current_Worker (worker_index))
+		{
+			Con_Printf ("Tasks : Failed to pin worker %d (N/A or no access rights)", worker_index);
+		}
+	}
+
 	while (true)
 	{
 		uint32_t task_index = TaskQueuePop (executable_task_queue);
@@ -339,6 +420,45 @@ static int Task_Worker (void *data)
 	return 0;
 }
 
+static void parse_pinned_workers (void)
+{
+	// defaults:
+	num_pinned_workers = 0;
+
+	const int pinned_workers_param_index = COM_CheckParm ("-pinnedworkers");
+
+	if (pinned_workers_param_index && pinned_workers_param_index < com_argc - 1)
+	{
+		size_t max_num_workers = 0;
+
+		char **fields = q_strsplit (com_argv[pinned_workers_param_index + 1], ",", &max_num_workers);
+
+		for (size_t core_index = 0; core_index < max_num_workers; core_index++)
+		{
+			const size_t core_id_len = strlen (fields[core_index]);
+
+			// test if all are digits
+			for (size_t j = 0; j < core_id_len; j++)
+			{
+				if (!q_isdigit ((int)fields[core_index][j]))
+				{
+					// invalid input, invalidate all
+					Mem_Free (fields);
+					num_pinned_workers = 0;
+					return;
+				}
+			}
+
+			pinned_workers_core_ids[num_pinned_workers++] = strtol (fields[core_index], NULL, 0) % SDL_GetCPUCount ();
+		}
+
+		Mem_Free (fields);
+
+		// override num_works with the number of valid fields
+		num_workers = num_pinned_workers;
+	}
+}
+
 /*
 ====================
 Tasks_Init
@@ -362,18 +482,23 @@ void Tasks_Init (void)
 
 	num_workers = CLAMP (1, SDL_GetCPUCount (), TASKS_MAX_WORKERS);
 
+	// num_workers is overriden by -pinnedworkers number of fields
+	parse_pinned_workers ();
+
 	// Fill lookup table to avoid modulo in Task_ExecuteIndexed
 	for (int i = 0; i < num_workers; ++i)
 	{
 		steal_worker_indices[i] = i;
-		steal_worker_indices[i + num_workers] = i;
+
+		// Workaround for "error: writing 16 bytes into a region of size 0 [-Werror=stringop-overflow=]"
+		size_t steal_index = CLAMP (0, (size_t)(i + num_workers), countof (steal_worker_indices) - 1);
+		steal_worker_indices[steal_index] = i;
 	}
 
 	indexed_task_counters = Mem_Alloc (sizeof (task_counter_t) * num_workers * MAX_PENDING_TASKS);
-	worker_threads = (SDL_Thread **)Mem_Alloc (sizeof (SDL_Thread *) * num_workers);
 	for (int i = 0; i < num_workers; ++i)
 	{
-		worker_threads[i] = SDL_CreateThread (Task_Worker, "Task_Worker", (void *)(intptr_t)i);
+		SDL_DetachThread (SDL_CreateThread (Task_Worker, va ("Task_Worker_%d", i), (void *)(intptr_t)i));
 	}
 }
 
@@ -507,9 +632,9 @@ Task_AddDependency
 */
 void Task_AddDependency (task_handle_t before, task_handle_t after)
 {
-	uint32_t  before_task_index = IndexFromTaskHandle (before);
-	task_t	 *before_task = &tasks[before_task_index];
-	const int before_handle_task_epoch = EpochFromTaskHandle (before);
+	uint32_t	   before_task_index = IndexFromTaskHandle (before);
+	task_t		  *before_task = &tasks[before_task_index];
+	const uint64_t before_handle_task_epoch = EpochFromTaskHandle (before);
 	SDL_LockMutex (before_task->epoch_mutex);
 	if (before_task->epoch != before_handle_task_epoch)
 	{
@@ -533,8 +658,8 @@ Task_Join
 */
 qboolean Task_Join (task_handle_t handle, uint32_t timeout)
 {
-	task_t	 *task = &tasks[IndexFromTaskHandle (handle)];
-	const int handle_task_epoch = EpochFromTaskHandle (handle);
+	task_t		  *task = &tasks[IndexFromTaskHandle (handle)];
+	const uint64_t handle_task_epoch = EpochFromTaskHandle (handle);
 	SDL_LockMutex (task->epoch_mutex);
 	while (task->epoch == handle_task_epoch)
 	{
